@@ -14,14 +14,14 @@ class TimeSeriesInterpretorRNN:
     self.features = features
 
   def monthly_chart(self):
-    model,background,test,features = self.model,self.background,self.test,self.features
+    model,background,test,features,max_output= self.model,self.background,self.test,self.features,self.max_output
     e = shap.DeepExplainer(model, background)
     shap_values = e.shap_values(test,check_additivity=False)
 
     d1=model.predict_generator(test)-e.expected_value
     d2=shap_values[0][0].sum()
     d3=d2/d1
-    shap_values=(shap_values[0][0]/d3)
+    shap_values=(shap_values/d3)
 
     shap_df=(pd.DataFrame(shap_values[0][0])).sum(axis=1)
 
@@ -90,7 +90,7 @@ class TimeSeriesInterpretorRNN:
     d1=model.predict_generator(test)-e.expected_value
     d2=shap_values[0][0].sum()
     d3=d2/d1
-    shap_values=(shap_values[0][0]/d3)
+    shap_values=(shap_values/d3)
     shap_df=(pd.DataFrame(shap_values[0][0])).sum(axis=1)
 
     p1=shap.summary_plot(shap_values[0][0],test[0],features,plot_type="bar")
@@ -106,7 +106,7 @@ class TimeSeriesInterpretorRNN:
     d1=model.predict_generator(test)-e.expected_value
     d2=shap_values[0][0].sum()
     d3=d2/d1
-    shap_values=(shap_values[0][0]/d3)
+    shap_values=(shap_values/d3)
 
     shap_df=(pd.DataFrame(shap_values[0][0])).sum(axis=1)
     test_df=pd.DataFrame(test[0])
@@ -123,7 +123,7 @@ class TimeSeriesInterpretorRNN:
     d1=model.predict_generator(test)-e.expected_value
     d2=shap_values[0][0].sum()
     d3=d2/d1
-    shap_values=(shap_values[0][0]/d3)
+    shap_values=(shap_values/d3)
     shap_df=(pd.DataFrame(shap_values[0][0])).sum(axis=1)
     shap_df_plot=pd.DataFrame(shap_values[0][0])
     test_df=pd.DataFrame(test[0])
